@@ -6,7 +6,6 @@ from typing import List, Optional, Union
 
 from packaging.version import Version
 
-from commitizen.git import GitCommit
 from commitizen.defaults import (
     MAJOR,
     MINOR,
@@ -15,6 +14,7 @@ from commitizen.defaults import (
     bump_message,
     bump_pattern,
 )
+from commitizen.git import GitCommit
 
 
 def find_increment(
@@ -34,12 +34,12 @@ def find_increment(
                 continue
             found_keyword = result.group(0)
             new_increment = increments_map_default[found_keyword]
-            if new_increment == "MAJOR":
-                increment = new_increment
-                break
-            elif increment == "MINOR" and new_increment == "PATCH":
+            if increment == "MAJOR":
                 continue
-            increment = new_increment
+            elif increment == "MINOR" and new_increment == "MAJOR":
+                increment = new_increment
+            elif increment == "PATCH" or increment is None:
+                increment = new_increment
 
     return increment
 
