@@ -1,3 +1,4 @@
+import warnings
 from typing import Optional
 
 from commitizen.defaults import DEFAULT_SETTINGS
@@ -22,7 +23,7 @@ class BaseConfig:
         For now only strings are supported.
         We use to update the version number.
         """
-        return self
+        raise NotImplementedError()
 
     def update(self, data: dict):
         self._settings.update(data)
@@ -32,3 +33,16 @@ class BaseConfig:
 
     def _parse_setting(self, data: str) -> dict:
         raise NotImplementedError()
+
+    # TODO: remove "files" supported in 2.0
+    @classmethod
+    def _show_files_column_deprecated_warning(cls):
+        warnings.simplefilter("always", DeprecationWarning)
+        warnings.warn(
+            (
+                '"files" is renamed as "version_files" '
+                "and will be deprecated in next major version\n"
+                'Please repalce "files" with "version_files"'
+            ),
+            category=DeprecationWarning,
+        )
