@@ -10,6 +10,10 @@ class TomlConfig(BaseConfig):
         self._parse_setting(data)
         self.add_path(path)
 
+    def init_empty_config_content(self):
+        with open(self.path, "a") as toml_file:
+            toml_file.write("[tool.commitizen]")
+
     def set_key(self, key, value):
         """Set or update a key in the conf.
 
@@ -37,3 +41,7 @@ class TomlConfig(BaseConfig):
             self.settings.update(doc["tool"]["commitizen"])
         except exceptions.NonExistentKey:
             self.is_empty_config = True
+
+        if "files" in self.settings:
+            self.settings["version_files"] = self.settings["files"]
+            TomlConfig._show_files_column_deprecated_warning
