@@ -22,8 +22,8 @@ class BaseCommitizen(metaclass=ABCMeta):
 
     def __init__(self, config: dict):
         self.config = config
-        if not self.config.get("style"):
-            self.config["style"] = BaseCommitizen.default_style_config
+        if not self.config.settings.get("style"):
+            self.config.settings.update({"style": BaseCommitizen.default_style_config})
 
     @abstractmethod
     def questions(self) -> list:
@@ -36,7 +36,10 @@ class BaseCommitizen(metaclass=ABCMeta):
     @property
     def style(self):
         return merge_styles(
-            [Style(BaseCommitizen.default_style_config), Style(self.config["style"])]
+            [
+                Style(BaseCommitizen.default_style_config),
+                Style(self.config.settings["style"]),
+            ]
         )
 
     def example(self) -> str:
@@ -47,6 +50,10 @@ class BaseCommitizen(metaclass=ABCMeta):
         """Schema definition of the commit message."""
         raise NotImplementedError("Not Implemented yet")
 
+    def schema_pattern(self) -> str:
+        """Regex matching the schema used for message validation"""
+        raise NotImplementedError("Not Implemented yet")
+
     def info(self) -> str:
         """Information about the standardized commit message."""
         raise NotImplementedError("Not Implemented yet")
