@@ -172,7 +172,7 @@ class ConventionalCommitsCz(BaseCommitizen):
     def schema_pattern(self) -> str:
         PATTERN = (
             r"(build|ci|docs|feat|fix|perf|refactor|style|test|chore|revert|bump)"
-            r"(\([\w\-]+\))?:\s.*"
+            r"(\(\S+\))?:\s.*"
         )
         return PATTERN
 
