@@ -1,12 +1,13 @@
 name: str = "cz_conventional_commits"
 # TODO: .cz, setup.cfg, .cz.cfg should be removed in 2.0
-config_files: list = ["pyproject.toml", ".cz.toml", ".cz", "setup.cfg", ".cz.cfg"]
-
+long_term_support_config_files: list = ["pyproject.toml", ".cz.toml"]
+deprcated_config_files: list = [".cz", "setup.cfg", ".cz.cfg"]
+config_files: list = long_term_support_config_files + deprcated_config_files
 
 DEFAULT_SETTINGS = {
     "name": "cz_conventional_commits",
     "version": None,
-    "files": [],
+    "version_files": [],
     "tag_format": None,  # example v$version
     "bump_message": None,  # bumped v$current_version to $new_version
 }
